
exports.up = function (knex, Promise) {
    return knex.schema.createTable('messages_events', function (table) {
        table.integer('mid').primary().notNullable() //(non-nullable) primary key
            .references('mid').inTable('messages')
            .onDelete('CASCADE'); 
        table.timestamps(true, true); //adds timestamptz-type (a PostgresQL data type) updated_at and created_at columns

        table.string('title').notNullable();
        table.text('content').notNullable();
        table.string('location').notNullable();
        table.dateTime('start_time').notNullable();
        table.dateTime('end_time').notNullable(); //TODO: add a CHECK (https://www.postgresql.org/docs/current/ddl-constraints.html) that start_time < end_time

        /*
        Les auteurs et destinataires des évenements sont dans les tables events_authors et events_recipients
        table.string('recipient',128).notNullable().defaultTo('noone')
            .references('gid').inTable('groups')
            .onDelete('SET DEFAULT'); //if recipient is deleted, direct to the special "no-one" group
        //TODO: for now, we support only 1 author (where as graphql schema indicates support for [Group] authors)

        table.string('author',128).notNullable()
            .references('gid').inTable('groups')
            .onDelete('CASCADE'); //delete message if author is deleted
        */

        /* We cannot define this yet because the table has not been created 
        table.integer('for_announcement')
            .references('mid').inTable('messages_announcements')
            .onDelete('SET NULL');
        */

        //participatingGroups and participatingUsers from the graphql schema are in tables `events_participating_groups` and `events_participating_users`

    });
};

exports.down = function (knex, Promise) {
    return knex.schema.dropTable('messages_events');
};
